@@ -106,6 +106,34 @@ class MutuallyExclusiveOption(click.Option):
             args
         )
 
+def create_and_add_to_pretty_table(table_fields, returned_alerts):
+    """
+    Function to create a table for output and adding rows based on the header fields passed
+
+    Args:
+        table_fields: list of column names
+        returned_alerts: list of alerts
+
+    Returns:
+        PrettyTable object
+    """
+    format_table = PrettyTable(table_fields)
+    for item in returned_alerts:
+        item_to_add = []
+        for field in table_fields:
+            if field == 'createdAt':
+                item_to_add.append((pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam').to_datetime_string())
+            elif field == 'message':
+                item_to_add.append(item['message'].replace("\n", ""))
+            elif field == 'integration':
+                item_to_add.append(item['integration']['name'])
+            elif field == 'tags':
+                if item['tags']: item_to_add.append(' '.join(sorted(item['tags'])))
+            elif field in format_table.field_names:
+                if item[field]: item_to_add.append(item[field])
+        format_table.add_row(item_to_add)
+    return format_table
+
 
 @click.group()
 @click.pass_context
@@ -191,24 +219,27 @@ def alerts(context):  # pylint: disable=unused-argument
 @alerts.command(name='query',
                 help='Example: "status: closed AND teams: <opsgenie-team> AND description: *<some-hostname>*"')
 @click.option('--query', required=True)
+@click.option('--sort-by', "--sort_by", default='status')
 @click.pass_context
-def alerts_query(context, query):
+def alerts_query(context, query, sort_by):
     """
     Function to query alerts
 
     Args:
         query: a query to filter the alerts
+        sort_by: which column to filter by
 
     Returns:
-        The json output of the alerts on success, None otherwise
+        A table output of the alerts on success and a string otherwise
 
     """
     result = context.obj['opsgenie'].query_alerts(query)
-    format_table = PrettyTable(['message', 'tags', 'integration', 'createdAt'])
-    for alert in result['data']:
-        format_table.add_row([alert['message'], alert['tags'], alert['integration']['type'], alert['createdAt']])
-    print(format_table)
+    sortedlist = sorted(result, key=itemgetter(sort_by))
+    table_fields = ['message', 'tags', 'integration', 'createdAt']
+    format_table = create_and_add_to_pretty_table(table_fields, sortedlist)
 
+    output = format_table if len(format_table._rows) > 0 else 'No alerts found..'
+    print(output)
 
 @alerts.command(name='list')
 @click.option('--active', default=False, is_flag=True)
@@ -216,9 +247,10 @@ def alerts_query(context, query):
 @click.option('--team-name', 'team_name', default=False)
 @click.option('--out-of-office-hours', default=False, is_flag=True)
 @click.option('--not-filtered', default=False, is_flag=True)
+@click.option('--sort-by', "--sort_by", default='status')
 @click.option('--limit', default=100)
 @click.pass_context
-def alerts_list(context, active, limit, more_info, team_name, out_of_office_hours, not_filtered):  # pylint: disable=too-many-branches
+def alerts_list(context, active, limit, more_info, team_name, out_of_office_hours, not_filtered, sort_by):  # pylint: disable=too-many-branches
     """
     Function to list alerts
 
@@ -227,6 +259,7 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
         limit: amount of alerts shown in output, default is 100
         more_info: adds the column tags, source, and integration to the output
         team_name: shows the alerts for the team specified
+        sort_by: which column to filter by
 
     Returns:
         Table output of the list of alerts on success
@@ -245,40 +278,26 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
     else:
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name}", limit)
-    sortedlist = sorted(result, key=itemgetter('status'))
+    sortedlist = sorted(result, key=itemgetter(sort_by))
 
     if more_info:
-        format_table = PrettyTable(['id', 'name', 'status', 'acknowledged',
-                                    'createdAt', 'tags', 'source', 'integration'])
+        table_fields = ['message', 'status', 'acknowledged',
+                                    'createdAt', 'tags', 'source', 'integration', 'id']
     else:
-        format_table = PrettyTable(['id', 'name', 'status', 'acknowledged', 'createdAt'])
-    for item in sortedlist:
-        if out_of_office_hours:
-            alert_dt = (pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')
-            if not item['tags']:
-                item['tags'] = None
-            if (alert_dt.hour >= 17) or (alert_dt.hour < 8):
-                if more_info:
-                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
-                                          alert_dt.to_datetime_string(), item['tags'], item['source'], item['integration']['name']])
-                else:
-                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], alert_dt.to_datetime_string()])
-        elif active:
-            if item['status'] == 'open' and not item['acknowledged']:
-                created_at = ((pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')).to_datetime_string()
-                if more_info:
-                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
-                                          created_at, item['tags'], item['source'], item['integration']['name']])
-                else:
-                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], created_at])
-        else:
-            created_at = ((pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')).to_datetime_string()
-            if more_info:
-                format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
-                                      created_at, item['tags'], item['source'], item['integration']['name']])
-            else:
-                format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], created_at])
-    print(format_table)
+        table_fields = ['message', 'status', 'acknowledged', 'createdAt']
+
+    if out_of_office_hours:
+        sortedlist = [x for x in sortedlist  \
+                        if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour >= 17 \
+                        or (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour < 8]
+    if active:
+        sortedlist = [x for x in sortedlist if x['status'] == 'open' and not x['acknowledged']]
+
+    table_fields = ['message', 'tags', 'integration', 'createdAt']
+    format_table = create_and_add_to_pretty_table(table_fields, sortedlist)
+
+    output = format_table if len(format_table._rows) > 0 else 'No alerts found..'
+    print(output)
 
 
 @alerts.command(cls=DefaultHelp, name='get')
@@ -324,19 +343,18 @@ def alerts_count(context, team_name, not_filtered, out_of_office_hours, limit):
         raise click.UsageError(
             "Specify the teamname using --teamname."
         )
+
     if not_filtered:
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
     else:
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name}", limit)
+
     if out_of_office_hours:
-        alerts = []
-        for alert in result:
-            alert_dt = pendulum.parse(alert['createdAt'])
-            if (alert_dt.hour >= 17) or (alert_dt.hour < 8):
-                alerts += [alert]
-    else:
-        alerts = result
-    dictionary = collections.Counter(item['message'] for item in alerts)
+        result = [x for x in result  \
+                        if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour >= 17 \
+                        or (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour < 8]
+
+    dictionary = collections.Counter(item['message'] for item in result)
     sorted_by_count = sorted(dictionary.items(), reverse=True, key=itemgetter(1))
     for alert in sorted_by_count:
         print(f"{alert[1]} - {alert[0]}")
@@ -732,58 +750,6 @@ def policy_alerts_delete(context, id_, all_, team_id, filter_, team_name):  # py
             "Use --id, --all or --filter to delete one or multiple alert policies"
         )
 
-# @policy_alerts.command(cls=DefaultHelp, name='set')
-# @click.option('--name', help='Name of the policy.')
-# @click.option('--enabled', default=True, is_flag=True, help='Initial status of the integration.')
-# @click.option('--team-id', 'team_id', help='Specify the team id.')
-#               # Later? functionality that by default grabs the teamid from the config.
-# @click.option('--message', default='{{message}}', help='Message of the alert.')
-# @click.option('--filter_type', type=click.Choice(['match-all', 'match-any-condition', 'match-all-conditions']),
-#               help='The type of filtering the policy applies for the alerts.')
-# @click.option('--filter_type', type=click.Choice(['match-all', 'match-any-condition', 'match-all-conditions']),
-#               help='The type of filtering the policy applies for the alerts.')
-# @click.pass_context
-# def policy_alerts_set(context, id, all, team_id):  # pylint: disable=redefined-builtin, invalid-name
-#     """
-#     Function to delete a single or multiple alerts
-
-#     Args:
-#         id: the id of the alert policy
-#         all: shows all alert policies that will be deleted, deletion follows after a prompts
-#         team_id: the id of the team to remove alert policies for
-
-#     Returns:
-#         String output specifying which alert policy id was removed and for which team on success, None otherwise
-
-#     """
-#     if {context.obj.get('teamid')} and not team_id:
-#         team_id = f"{context.obj.get('teamid')}"
-#     if not {context.obj.get('teamid')} and not team_id:
-#         raise click.UsageError(
-#             "Specify the team id using --team_id."
-#         )
-#     if id:
-#         response = context.obj['opsgenie'].delete_alert_policy(id, team_id)
-#         if response['result'] == 'Deleted':
-#             print(f"✓ - alert policy {id} deleted for team: {context.obj.get('teamname')}")
-#         else:
-#             print(response.text)
-#             sys.exit(1)
-#     if all:
-#         reponse = context.obj['opsgenie'].list_alert_policy(team_id)
-#         print("The following alerts policies will be deleted:")
-#         for item in reponse['data']:
-#             print(f"{item['id']} - {item['name']}")
-#         value = click.confirm('\nDo you want to continue?', abort=True)
-#         if value:
-#             for item in reponse['data']:
-#                 response = context.obj['opsgenie'].delete_alert_policy(f"{item['id']}", team_id)
-#                 if response['result'] == 'Deleted':
-#                     print(f"✓ - alert policy {item['id']} deleted for team: {context.obj.get('teamname')}")
-#                 else:
-#                     print(response.text)
-#                     sys.exit(1)
-
 
 @bootstrapper.group()
 @click.pass_context
@@ -1191,10 +1157,10 @@ def policy_maintenance_list(context, nonexpired, past):
     format_table = PrettyTable(['id', 'status', 'description', 'type', 'startdate', 'enddate'])
     for item in result['data']:
         if 'endDate' in item['time']:
-            end_date = (pendulum.parse(item['time']['endDate'])).to_datetime_string()
+            end_date = ((pendulum.parse(item['time']['endDate'])).in_tz('Europe/Amsterdam')).to_datetime_string()
         else:
             end_date = None
-        start_date = (pendulum.parse(item['time']['startDate'])).to_datetime_string()
+        start_date = ((pendulum.parse(item['time']['startDate'])).in_tz('Europe/Amsterdam')).to_datetime_string()
         format_table.add_row([item['id'], item['status'], item['description'],
                               item['time']['type'], start_date, end_date])
     print(format_table)
